#!/bin/bash
#
# collectd    Startup script for the Collectd statistics gathering daemon
# chkconfig: - 86 14
# description: Collectd is a statistics gathering daemon used to collect \
#   system information ie. cpu, memory, disk, network
# processname: collectd
# config: /etc/opt/hde/collectd.conf
# config: /etc/sysconfig/hde-collectd
# pidfile: /var/run/hde-collectd.pid

# define vendor variables.
VENDOR_PREFIX=/opt/hde
VENDOR_BINDIR=${VENDOR_PREFIX}/bin
VENDOR_SBINDIR=${VENDOR_PREFIX}/sbin
VENDOR_DATADIR=/var${VENDOR_PREFIX}
VENDOR_SYSCONFDIR=/etc${VENDOR_PREFIX}

# Source function library.
. /etc/init.d/functions

RETVAL=0
ARGS=""
export PATH=$PATH:${VENDOR_SBINDIR}:${VENDOR_BINDIR}
prog="collectdmon"
SERVICE=hde-collectd
CONFIG=${VENDOR_SYSCONFDIR}/collectd.conf
COLLECTD=${VENDOR_SBINDIR}/collectd
COLLECTDMONPID=/var/run/${SERVICE}.pid

if [ -r /etc/sysconfig/${SERVICE} ]; then
	. /etc/sysconfig/${SERVICE}
fi

start () {
	echo -n $"Starting ${SERVICE}: "
	if [ -r "$CONFIG" ]
	then
		daemon $prog -P $COLLECTDMONPID -c $COLLECTD -- -C "$CONFIG"
		RETVAL=$?
		echo
		[ $RETVAL -eq 0 ] && touch /var/lock/subsys/${SERVICE}
	fi
}
stop () {
	echo -n $"Stopping ${SERVICE}: "
	killproc $prog
	RETVAL=$?
	echo
	[ $RETVAL -eq 0 ] && rm -f /var/lock/subsys/${SERVICE}
}
# See how we were called.
case "$1" in
  start)
	start
	;;
  stop)
	stop
	;;
  status)
	status $prog
	;;
  restart|reload)
	stop
	start
	;;
  condrestart)
	if [ -f /var/lock/subsys/${SERVICE} ]; then
		stop
		start
	fi
	;;
  *)
	echo $"Usage: $0 {start|stop|status|restart|reload|condrestart}"
	exit 1
esac

exit $?

# vim:syntax=sh
